==> haskell-contravariant-extras-0.3.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-contravariant-extras/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.1
id: contravariant-extras-0.3.1-496f24542da6aeee5af60b77617dfbfa
key: contr_LNWWfqJt9dyDzeR3aPXtV5
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-extras-0.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-extras-0.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/contravariant-extras-0.3.1
hs-libraries: HScontravariant-extras-0.3.1-LNWWfqJt9dyDzeR3aPXtV5
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-prelude-1-f3d581c11ed30ed2219a781ec92d2bd3
    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    tuple-th-0.2.5-ea7f98b57800e457206c4356ae606852
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-extras-0.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-contravariant-extras/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.1
id: contravariant-extras-0.3.1-2b0831e162b39d8a01f0f90a5517b5db
key: contr_GwEJXpCFufKFju2IjGfwlT
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-extras-0.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-extras-0.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/contravariant-extras-0.3.1
hs-libraries: HScontravariant-extras-0.3.1-GwEJXpCFufKFju2IjGfwlT
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-prelude-1-f3d581c11ed30ed2219a781ec92d2bd3
    contravariant-1.4-1bd57c2540cd2864a467c8bf62a3fdb4
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    tuple-th-0.2.5-ea7f98b57800e457206c4356ae606852
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
